==> haskell-config-schema-1.3.0.0-123-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-config-schema.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 config-schema
version:              1.3.0.0
visibility:           public
id:                   config-schema-1.3.0.0-JC33bUVTImE2AuZxfKQf5I
key:                  config-schema-1.3.0.0-JC33bUVTImE2AuZxfKQf5I
license:              ISC
copyright:            Eric Mertens 2017
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/config-schema
synopsis:             Schema definitions for the config-value package
description:
    This package makes it possible to define schemas for use when
    loading configuration files using the config-value format.
    These schemas can be used to process a configuration file into
    a Haskell value or to automatically generate documentation for
    the file format.

category:             Language
abi:                  1502e324b746f2f92cbe959a5084f483
exposed:              True
exposed-modules:
    Config.Schema Config.Schema.Docs Config.Schema.Load
    Config.Schema.Load.Error Config.Schema.Spec Config.Schema.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/config-schema-1.3.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/config-schema-1.3.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/config-schema-1.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-config-schema
hs-libraries:         HSconfig-schema-1.3.0.0-JC33bUVTImE2AuZxfKQf5I
depends:
    base-4.17.2.1 config-value-0.8.3-AwfdtSmE9Y1aqPSXDWTLH
    containers-0.6.7 free-5.2-6XzfBaBNYAXDXFzJJLivZy
    kan-extensions-5.2.6-KBwUD7iE9mqDwBNzY0H3ht pretty-1.1.3.6
    semigroupoids-6.0.0.1-EsDekxjOCgO6Hkl2ZFNy0d text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-config-schema/html/config-schema.haddock

haddock-html:         /usr/share/doc/haskell-config-schema/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-config-schema-1.3.0.0-124-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-config-schema.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 config-schema
version:              1.3.0.0
visibility:           public
id:                   config-schema-1.3.0.0-JaetV8PqydbEgugzdolfbp
key:                  config-schema-1.3.0.0-JaetV8PqydbEgugzdolfbp
license:              ISC
copyright:            Eric Mertens 2017
maintainer:           emertens@gmail.com
author:               Eric Mertens
homepage:             https://github.com/glguy/config-schema
synopsis:             Schema definitions for the config-value package
description:
    This package makes it possible to define schemas for use when
    loading configuration files using the config-value format.
    These schemas can be used to process a configuration file into
    a Haskell value or to automatically generate documentation for
    the file format.

category:             Language
abi:                  c4f79d36d0af1e30972832c2667858b8
exposed:              True
exposed-modules:
    Config.Schema Config.Schema.Docs Config.Schema.Load
    Config.Schema.Load.Error Config.Schema.Spec Config.Schema.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/config-schema-1.3.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/config-schema-1.3.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/config-schema-1.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-config-schema
hs-libraries:         HSconfig-schema-1.3.0.0-JaetV8PqydbEgugzdolfbp
depends:
    base-4.17.2.1 config-value-0.8.3-AwfdtSmE9Y1aqPSXDWTLH
    containers-0.6.7 free-5.2-CbYHK2gYcEs2aFQR5gxgcO
    kan-extensions-5.2.6-Bk5xiYmHYdL4IRd0HLdbOL pretty-1.1.3.6
    semigroupoids-6.0.0.1-At7Omlh9GqgC8Sb6O7re5 text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-config-schema/html/config-schema.haddock

haddock-html:         /usr/share/doc/haskell-config-schema/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
